@@ -147,21 +147,23 @@ class Cadreur(QObject):
                 hautgauche = (p + self.decal - self.rayons) * ech
                 taille = self.sz * ech
                 self.capture.set(cv2.CAP_PROP_POS_FRAMES, i + self.app.premiere_image)
-                status, img =  self.capture.read()
+                try:
+                    status, img =  self.capture.read()
 
-                x, y = int(hautgauche.x()), int(hautgauche.y())
-                w, h = int(taille.x()), int(taille.y())
+                    x, y = int(hautgauche.x()), int(hautgauche.y())
+                    w, h = int(taille.x()), int(taille.y())
 
-                crop_img = img[y:y+h, x:x+w] # Crop from x, y, w, h -> 100, 200, 300, 400
-                # NOTE: its img[y: y + h, x: x + w] and *not* img[x: x + w, y: y + h]
-
-                cv2.imshow(self.titre, crop_img)
-                k = cv2.waitKey(int(self.delay * self.ralenti))
-                if k == 0x10001b or k == 27 or k==20:
-                    fini = True
-                    cv2.destroyAllWindows()
-                    break
+                    crop_img = img[y:y+h, x:x+w] # Crop from x, y, w, h -> 100, 200, 300, 400
+                    # NOTE: its img[y: y + h, x: x + w] and *not* img[x: x + w, y: y + h]
 
+                    cv2.imshow(self.titre, crop_img)
+                    k = cv2.waitKey(int(self.delay * self.ralenti))
+                    if k == 0x10001b or k == 27 or k==20:
+                        fini = True
+                        cv2.destroyAllWindows()
+                        break
+                except:
+                    fini=True
         cv2.destroyAllWindows()
         fini = True
 
